# coconut-ai

## About

Coconut AI

<https://pypi.org/project/coconut-ai/>

## Getting Started

### Prerequisites

- [Python](https://www.python.org/) v3.10
- [Pipenv](https://pipenv.pypa.io/)
- [Pip](https://pypi.org/project/pip/)

### Installation

```sh
git clone git@github.com:sae-llm-coconut/coconut-ai.git
cd coconut-ai
pipenv install --dev
```

### Usage

```sh
pipenv run start
```

## 💡 Contributing

Anyone can help to improve the project, submit a Feature Request, a bug report or even correct a simple spelling mistake.

The steps to contribute can be found in the [CONTRIBUTING.md](./CONTRIBUTING.md) file.

## 📄 License

[MIT](./LICENSE)
